@@ -32,7 +32,7 @@ def test_jump_map():
     pos_map = source_map["pc_pos_map"]
     jump_map = source_map["pc_jump_map"]
 
-    assert len([v for v in jump_map.values() if v == "o"]) == 3
+    assert len([v for v in jump_map.values() if v == "o"]) == 1
     assert len([v for v in jump_map.values() if v == "i"]) == 2
 
     code_lines = [i + "\n" for i in TEST_CODE.split("\n")]
@@ -62,7 +62,7 @@ def test_pos_map_offsets():
             lineno, col_offset, end_lineno, end_col_offset = next(pc_iter)
             assert code_lines[lineno - 1][col_offset] == TEST_CODE[start]
             assert length == (
-                sum(len(i) for i in code_lines[lineno - 1 : end_lineno])  # noqa: E203
+                sum(len(i) for i in code_lines[lineno - 1 : end_lineno])
                 - col_offset
                 - (len(code_lines[end_lineno - 1]) - end_col_offset)
             )
