@@ -127,7 +127,8 @@ def _parse_docstring(
                 raise NatSpecSyntaxException("Method does not return any values", *err_args)
             if len(natspec["returns"]) >= return_length:
                 raise NatSpecSyntaxException(
-                    "Number of documented return values exceeds actual number", *err_args,
+                    "Number of documented return values exceeds actual number",
+                    *err_args,
                 )
             key = f"_{len(natspec['returns'])}"
 
@@ -139,7 +140,9 @@ def _parse_docstring(
         natspec["notice"] = " ".join(docstring.split())
     elif not docstring.strip().startswith("@"):
         raise NatSpecSyntaxException(
-            "NatSpec docstring opens with untagged comment", source, *line_no.offset_to_line(start),
+            "NatSpec docstring opens with untagged comment",
+            source,
+            *line_no.offset_to_line(start),
         )
 
     return natspec
