@@ -331,8 +331,12 @@ class VyperNode:
     def __repr__(self):
         cls = type(self)
         class_repr = f"{cls.__module__}.{cls.__qualname__}"
+        return f"{class_repr}:\n{self._annotated_source}"
 
-        source_annotation = annotate_source_code(
+    @property
+    def _annotated_source(self):
+        # return source with context / line/col info
+        return annotate_source_code(
             self.full_source_code,
             self.lineno,
             self.col_offset,
@@ -340,8 +344,6 @@ class VyperNode:
             line_numbers=VYPER_ERROR_LINE_NUMBERS,
         )
 
-        return f"{class_repr}:\n{source_annotation}"
-
     @property
     def description(self):
         """
