@@ -36,6 +36,7 @@ from vyper.codegen.types import (
     SArrayType,
     StringType,
     TupleType,
+    get_type_for_exact_size,
     is_base_type,
     is_bytes_m_type,
     parse_integer_typeinfo,
@@ -86,9 +87,11 @@ from vyper.utils import (
     DECIMAL_DIVISOR,
     MemoryPositions,
     SizeLimits,
+    abi_method_id,
     bytes_to_int,
     fourbytes_to_int,
     keccak256,
+    vyper_warn,
 )
 
 from .signatures import Optional, validate_inputs
@@ -1867,6 +1870,46 @@ class Empty:
         return IRnode("~empty", typ=output_type)
 
 
+class Print(_SimpleBuiltinFunction):
+    _id = "print"
+    _inputs = [("arg", "*")]
+
+    _warned = False
+
+    def fetch_call_return(self, node):
+        if not self._warned:
+            vyper_warn("`print` should only be used for debugging!\n" + node._annotated_source)
+            self._warned = True
+
+        validate_call_args(node, 1)
+        return None
+
+    @validate_inputs
+    def build_IR(self, expr, args, kwargs, context):
+        args = [Expr(arg, context).ir_node for arg in expr.args]
+        args_tuple_t = TupleType([x.typ for x in args])
+        args_as_tuple = IRnode.from_list(["multi"] + [x for x in args], typ=args_tuple_t)
+        args_abi_t = args_tuple_t.abi_type
+        # create a signature like "log(uint256)"
+        sig = "log" + "(" + ",".join([arg.typ.abi_type.selector_name() for arg in args]) + ")"
+        method_id = abi_method_id(sig)
+
+        buflen = 32 + args_abi_t.size_bound()
+
+        # 32 bytes extra space for the method id
+        buf = context.new_internal_variable(get_type_for_exact_size(buflen))
+
+        ret = ["seq"]
+        ret.append(["mstore", buf, method_id])
+        encode = abi_encode(buf + 32, args_as_tuple, context, buflen, returns_len=True)
+
+        # debug address that tooling uses
+        CONSOLE_ADDRESS = 0x000000000000000000636F6E736F6C652E6C6F67
+        ret.append(["staticcall", "gas", CONSOLE_ADDRESS, buf + 28, encode, 0, 0])
+
+        return IRnode.from_list(ret, annotation="print:" + sig)
+
+
 class ABIEncode(_SimpleBuiltinFunction):
     _id = "_abi_encode"  # TODO prettier to rename this to abi.encode
     # signature: *, ensure_tuple=<literal_bool> -> Bytes[<calculated len>]
@@ -2046,6 +2089,7 @@ DISPATCH_TABLE = {
 
 STMT_DISPATCH_TABLE = {
     "send": Send(),
+    "print": Print(),
     "selfdestruct": SelfDestruct(),
     "raw_call": RawCall(),
     "raw_log": RawLog(),
