@@ -8,11 +8,11 @@ from pathlib import Path
 from typing import Dict, Iterable, Iterator, Set, TypeVar
 
 import vyper
+import vyper.codegen.ir_node as ir_node
 from vyper.cli import vyper_json
 from vyper.cli.utils import extract_file_interface_imports, get_interface_file_path
 from vyper.compiler.settings import VYPER_TRACEBACK_LIMIT
 from vyper.evm.opcodes import DEFAULT_EVM_VERSION, EVM_VERSIONS
-from vyper.old_codegen import parser_utils
 from vyper.typing import ContractCodes, ContractPath, OutputFormats
 
 T = TypeVar("T")
@@ -33,8 +33,9 @@ interface          - Vyper interface of a contract
 external_interface - External interface of a contract, used for outside contract calls
 opcodes            - List of opcodes as a string
 opcodes_runtime    - List of runtime opcodes as a string
-ir                 - Intermediate representation in LLL
-ir_json            - Intermediate LLL representation in JSON format
+ir                 - Intermediate representation in list format
+ir_json            - Intermediate representation in JSON format
+hex-ir             - Output IR and assembly constants in hex instead of decimal
 no-optimize        - Do not optimize (don't use this for production code)
 """
 
@@ -87,11 +88,11 @@ def _parse_args(argv):
     parser.add_argument(
         "--version",
         action="version",
-        version=vyper.__version__,
+        version=f"{vyper.__version__}+commit.{vyper.__commit__}",
     )
     parser.add_argument(
         "--show-gas-estimates",
-        help="Show gas estimates in ir output mode.",
+        help="Show gas estimates in abi and ir output mode.",
         action="store_true",
     )
     parser.add_argument(
@@ -100,6 +101,12 @@ def _parse_args(argv):
         default="bytecode",
         dest="format",
     )
+    parser.add_argument(
+        "--storage-layout-file",
+        help="Override storage slots provided by compiler",
+        dest="storage_layout",
+        nargs="+",
+    )
     parser.add_argument(
         "--evm-version",
         help=f"Select desired EVM version (default {DEFAULT_EVM_VERSION})",
@@ -129,6 +136,10 @@ def _parse_args(argv):
         help="Switch to standard JSON mode. Use `--standard-json -h` for available options.",
         action="store_true",
     )
+    parser.add_argument(
+        "--hex-ir",
+        action="store_true",
+    )
     parser.add_argument(
         "-p", help="Set the root path for contract imports", default=".", dest="root_folder"
     )
@@ -148,6 +159,9 @@ def _parse_args(argv):
         # an error occurred in a Vyper source file.
         sys.tracebacklimit = 0
 
+    if args.hex_ir:
+        ir_node.AS_HEX_DEFAULT = True
+
     output_formats = tuple(uniq(args.format.split(",")))
 
     compiled = compile_files(
@@ -157,6 +171,7 @@ def _parse_args(argv):
         args.show_gas_estimates,
         args.evm_version,
         args.no_optimize,
+        args.storage_layout,
     )
 
     if args.output_path:
@@ -211,10 +226,36 @@ def get_interface_codes(root_path: Path, contract_sources: ContractCodes) -> Dic
             with valid_path.open() as fh:
                 code = fh.read()
                 if valid_path.suffix == ".json":
-                    interfaces[file_path][interface_name] = {
-                        "type": "json",
-                        "code": json.loads(code.encode()),
-                    }
+                    contents = json.loads(code.encode())
+
+                    # EthPM Manifest (EIP-2678)
+                    if "contractTypes" in contents:
+                        if (
+                            interface_name not in contents["contractTypes"]
+                            or "abi" not in contents["contractTypes"][interface_name]
+                        ):
+                            raise ValueError(
+                                f"Could not find interface '{interface_name}'"
+                                f" in manifest '{valid_path}'."
+                            )
+
+                        interfaces[file_path][interface_name] = {
+                            "type": "json",
+                            "code": contents["contractTypes"][interface_name]["abi"],
+                        }
+
+                    # ABI JSON file (either `List[ABI]` or `{"abi": List[ABI]}`)
+                    elif isinstance(contents, list) or (
+                        "abi" in contents and isinstance(contents["abi"], list)
+                    ):
+                        interfaces[file_path][interface_name] = {
+                            "type": "json",
+                            "code": contents,
+                        }
+
+                    else:
+                        raise ValueError(f"Corrupted file: '{valid_path}'")
+
                 else:
                     interfaces[file_path][interface_name] = {"type": "vyper", "code": code}
 
@@ -228,11 +269,9 @@ def compile_files(
     show_gas_estimates: bool = False,
     evm_version: str = DEFAULT_EVM_VERSION,
     no_optimize: bool = False,
+    storage_layout: Iterable[str] = None,
 ) -> OrderedDict:
 
-    if show_gas_estimates:
-        parser_utils.LLLnode.repr_show_gas = True
-
     root_path = Path(root_folder).resolve()
     if not root_path.exists():
         raise FileNotFoundError(f"Invalid root path - '{root_path.as_posix()}' does not exist")
@@ -249,6 +288,13 @@ def compile_files(
             # https://bugs.python.org/issue35107
             contract_sources[file_str] = fh.read() + "\n"
 
+    storage_layouts = OrderedDict()
+    if storage_layout:
+        for storage_file_name, contract_name in zip(storage_layout, contract_sources.keys()):
+            storage_file_path = Path(storage_file_name)
+            with storage_file_path.open() as sfh:
+                storage_layouts[contract_name] = json.load(sfh)
+
     show_version = False
     if "combined_json" in output_formats:
         if len(output_formats) > 1:
@@ -266,6 +312,8 @@ def compile_files(
         interface_codes=get_interface_codes(root_path, contract_sources),
         evm_version=evm_version,
         no_optimize=no_optimize,
+        storage_layouts=storage_layouts,
+        show_gas_estimates=show_gas_estimates,
     )
     if show_version:
         compiler_data["version"] = vyper.__version__
