@@ -25,7 +25,9 @@ TRANSLATE_MAP = {
     "evm.deployedBytecode.opcodes": "opcodes_runtime",
     "evm.deployedBytecode.sourceMap": "source_map",
     "interface": "interface",
-    "ir": "ir",
+    "ir": "ir_dict",
+    "ir_runtime": "ir_runtime_dict",
+    # "metadata": "metadata",  # don't include  in "*" output for now
     "layout": "layout",
     "userdoc": "userdoc",
 }
@@ -48,7 +50,7 @@ def _parse_args(argv):
     parser.add_argument(
         "--version",
         action="version",
-        version=vyper.__version__,
+        version=f"{vyper.__version__}+commit.{vyper.__commit__}",
     )
     parser.add_argument(
         "-o",
@@ -180,22 +182,47 @@ def get_input_dict_contracts(input_dict: Dict) -> ContractCodes:
 
 def get_input_dict_interfaces(input_dict: Dict) -> Dict:
     interface_sources: Dict = {}
+
     for path, value in input_dict.get("interfaces", {}).items():
         key = _standardize_path(path)
+
         if key.endswith(".json"):
-            if "abi" not in value:
+            # EthPM Manifest v3 (EIP-2678)
+            if "contractTypes" in value:
+                for name, ct in value["contractTypes"].items():
+                    if name in interface_sources:
+                        raise JSONError(f"Interface namespace collision: {name}")
+
+                    interface_sources[name] = {"type": "json", "code": ct["abi"]}
+
+                continue  # Skip to next interface
+
+            # ABI JSON file (`{"abi": List[ABI]}`)
+            elif "abi" in value:
+                interface = {"type": "json", "code": value["abi"]}
+
+            # ABI JSON file (`List[ABI]`)
+            elif isinstance(value, list):
+                interface = {"type": "json", "code": value}
+
+            else:
                 raise JSONError(f"Interface '{path}' must have 'abi' field")
-            interface = {"type": "json", "code": value["abi"]}
+
         elif key.endswith(".vy"):
             if "content" not in value:
                 raise JSONError(f"Interface '{path}' must have 'content' field")
+
             interface = {"type": "vyper", "code": value["content"]}
+
         else:
             raise JSONError(f"Interface '{path}' must have suffix '.vy' or '.json'")
+
         key = key.rsplit(".", maxsplit=1)[0]
         if key in interface_sources:
             raise JSONError(f"Interface namespace collision: {key}")
+
         interface_sources[key] = interface
+
     return interface_sources
 
 
@@ -212,13 +239,15 @@ def get_input_dict_output_formats(input_dict: Dict, contract_sources: ContractCo
             outputs.remove(key)
             outputs.update([i for i in TRANSLATE_MAP if i.startswith(key)])
         if "*" in outputs:
-            outputs = sorted(TRANSLATE_MAP.values())
+            outputs = TRANSLATE_MAP.values()
         else:
             try:
-                outputs = sorted(TRANSLATE_MAP[i] for i in outputs)
+                outputs = [TRANSLATE_MAP[i] for i in outputs]
             except KeyError as e:
                 raise JSONError(f"Invalid outputSelection - {e}")
 
+        outputs = sorted(set(outputs))
+
         if path == "*":
             output_keys = list(contract_sources.keys())
         else:
@@ -244,6 +273,11 @@ def get_interface_codes(
     code = contract_sources[contract_path]
     interface_codes = extract_file_interface_imports(code)
     for interface_name, interface_path in interface_codes.items():
+        # If we know the interfaces already (e.g. EthPM Manifest file)
+        if interface_name in interface_sources:
+            interfaces[interface_name] = interface_sources[interface_name]
+            continue
+
         path = Path(contract_path).parent.joinpath(interface_path).as_posix()
         keys = [_standardize_path(path)]
         if not interface_path.startswith("."):
@@ -277,7 +311,29 @@ def get_interface_codes(
         with valid_path.open() as fh:
             code = fh.read()
         if valid_path.suffix == ".json":
-            interfaces[interface_name] = {"type": "json", "code": json.loads(code.encode())}
+            code_dict = json.loads(code.encode())
+            # EthPM Manifest v3 (EIP-2678)
+            if "contractTypes" in code_dict:
+                if interface_name not in code_dict["contractTypes"]:
+                    raise JSONError(f"'{interface_name}' not found in '{valid_path}'")
+
+                if "abi" not in code_dict["contractTypes"][interface_name]:
+                    raise JSONError(f"Missing abi for '{interface_name}' in '{valid_path}'")
+
+                abi = code_dict["contractTypes"][interface_name]["abi"]
+                interfaces[interface_name] = {"type": "json", "code": abi}
+
+            # ABI JSON (`{"abi": List[ABI]}`)
+            elif "abi" in code_dict:
+                interfaces[interface_name] = {"type": "json", "code": code_dict["abi"]}
+
+            # ABI JSON (`List[ABI]`)
+            elif isinstance(code_dict, list):
+                interfaces[interface_name] = {"type": "json", "code": code_dict}
+
+            else:
+                raise JSONError(f"Unexpected type in file: '{valid_path}'")
+
         else:
             interfaces[interface_name] = {"type": "vyper", "code": code}
 
@@ -349,7 +405,10 @@ def format_to_output_dict(compiler_data: Dict) -> Dict:
         output_dict["contracts"][path] = {name: {}}
         output_contracts = output_dict["contracts"][path][name]
 
-        for key in ("abi", "devdoc", "interface", "ir", "userdoc"):
+        if "ir_dict" in data:
+            output_contracts["ir"] = data["ir_dict"]
+
+        for key in ("abi", "devdoc", "interface", "metadata", "userdoc"):
             if key in data:
                 output_contracts[key] = data[key]
 
@@ -357,14 +416,14 @@ def format_to_output_dict(compiler_data: Dict) -> Dict:
             output_contracts["evm"] = {"methodIdentifiers": data["method_identifiers"]}
 
         evm_keys = ("bytecode", "opcodes")
-        if next((i for i in evm_keys if i in data), False):
+        if any(i in data for i in evm_keys):
             evm = output_contracts.setdefault("evm", {}).setdefault("bytecode", {})
             if "bytecode" in data:
                 evm["object"] = data["bytecode"]
             if "opcodes" in data:
                 evm["opcodes"] = data["opcodes"]
 
-        if next((i for i in evm_keys if i + "_runtime" in data), False) or "source_map" in data:
+        if any(i + "_runtime" in data for i in evm_keys) or "source_map" in data:
             evm = output_contracts.setdefault("evm", {}).setdefault("deployedBytecode", {})
             if "bytecode_runtime" in data:
                 evm["object"] = data["bytecode_runtime"]
