@@ -7,6 +7,7 @@ from vyper.exceptions import (
     StructureException,
     UndeclaredDefinition,
 )
+from vyper.semantics.validation.levenshtein_utils import get_levenshtein_error_suggestions
 
 
 class Namespace(dict):
@@ -42,7 +43,8 @@ class Namespace(dict):
 
     def __getitem__(self, key):
         if key not in self:
-            raise UndeclaredDefinition(f"'{key}' has not been declared")
+            suggestions_str = get_levenshtein_error_suggestions(key, self, 0.2)
+            raise UndeclaredDefinition(f"'{key}' has not been declared. {suggestions_str}")
         return super().__getitem__(key)
 
     def __enter__(self):
@@ -176,6 +178,8 @@ RESERVED_KEYWORDS = {
     # `address` members
     "balance",
     "codesize",
+    "codehash",
+    "code",
     "is_contract",
     # units
     "units",
