@@ -6,7 +6,11 @@ from vyper.ast.validation import validate_call_args
 from vyper.exceptions import EventDeclarationException, NamespaceCollision, StructureException
 from vyper.semantics.namespace import validate_identifier
 from vyper.semantics.types.bases import DataLocation
-from vyper.semantics.types.utils import get_type_from_abi, get_type_from_annotation
+from vyper.semantics.types.utils import (
+    generate_abi_type,
+    get_type_from_abi,
+    get_type_from_annotation,
+)
 from vyper.semantics.validation.utils import validate_expected_type
 from vyper.utils import keccak256
 
@@ -39,7 +43,7 @@ class Event:
 
     @property
     def signature(self):
-        return f"{self.name}({','.join(v.canonical_type for v in self.arguments.values())})"
+        return f"{self.name}({','.join(v.canonical_abi_type for v in self.arguments.values())})"
 
     @classmethod
     def from_abi(cls, abi: Dict) -> "Event":
@@ -119,7 +123,7 @@ class Event:
             {
                 "name": self.name,
                 "inputs": [
-                    {"name": name, "type": typ.canonical_type, "indexed": idx}
+                    dict(**generate_abi_type(typ, name), **{"indexed": idx})
                     for (name, typ), idx in zip(self.arguments.items(), self.indexed)
                 ],
                 "anonymous": False,
