@@ -14,7 +14,6 @@ from vyper.exceptions import (
     NonPayableViolation,
     StateAccessViolation,
     StructureException,
-    SyntaxException,
     TypeMismatch,
     VariableDeclarationException,
     VyperException,
@@ -25,14 +24,21 @@ from vyper.semantics.environment import CONSTANT_ENVIRONMENT_VARS, MUTABLE_ENVIR
 from vyper.semantics.namespace import get_namespace
 from vyper.semantics.types.abstract import IntegerAbstractType
 from vyper.semantics.types.bases import DataLocation
-from vyper.semantics.types.function import ContractFunction, FunctionVisibility, StateMutability
-from vyper.semantics.types.indexable.sequence import ArrayDefinition, TupleDefinition
+from vyper.semantics.types.function import (
+    ContractFunction,
+    MemberFunctionDefinition,
+    StateMutability,
+)
+from vyper.semantics.types.indexable.sequence import (
+    ArrayDefinition,
+    DynamicArrayDefinition,
+    TupleDefinition,
+)
 from vyper.semantics.types.user.event import Event
-from vyper.semantics.types.user.struct import StructDefinition
 from vyper.semantics.types.utils import get_type_from_annotation
+from vyper.semantics.types.value.address import AddressDefinition
 from vyper.semantics.types.value.array_value import StringDefinition
 from vyper.semantics.types.value.boolean import BoolDefinition
-from vyper.semantics.types.value.numeric import Uint256Definition
 from vyper.semantics.validation.annotation import StatementAnnotationVisitor
 from vyper.semantics.validation.base import VyperNodeVisitorBase
 from vyper.semantics.validation.utils import (
@@ -111,6 +117,39 @@ def _validate_revert_reason(msg_node: vy_ast.VyperNode) -> None:
                 raise InvalidType("revert reason must fit within String[1024]") from e
 
 
+def _validate_address_code_attribute(node: vy_ast.Attribute) -> None:
+    value_type = get_exact_type_from_node(node.value)
+    if isinstance(value_type, AddressDefinition) and node.attr == "code":
+        # Validate `slice(<address>.code, start, length)` where `length` is constant
+        parent = node.get_ancestor()
+        if isinstance(parent, vy_ast.Call):
+            ok_func = isinstance(parent.func, vy_ast.Name) and parent.func.id == "slice"
+            ok_args = len(parent.args) == 3 and isinstance(parent.args[2], vy_ast.Int)
+            if ok_func and ok_args:
+                return
+        raise StructureException(
+            "(address).code is only allowed inside of a slice function with a constant length",
+            node,
+        )
+
+
+def _validate_msg_data_attribute(node: vy_ast.Attribute) -> None:
+    if isinstance(node.value, vy_ast.Name) and node.value.id == "msg" and node.attr == "data":
+        parent = node.get_ancestor()
+        if not isinstance(parent, vy_ast.Call) or parent.get("func.id") not in ("slice", "len"):
+            raise StructureException(
+                "msg.data is only allowed inside of the slice or len functions",
+                node,
+            )
+        if parent.get("func.id") == "slice":
+            ok_args = len(parent.args) == 3 and isinstance(parent.args[2], vy_ast.Int)
+            if not ok_args:
+                raise StructureException(
+                    "slice(msg.data) must use a compile-time constant for length argument",
+                    parent,
+                )
+
+
 class FunctionNodeVisitor(VyperNodeVisitorBase):
 
     ignored_types = (
@@ -129,16 +168,9 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
         self.namespace = namespace
         self.func = fn_node._metadata["type"]
         self.annotation_visitor = StatementAnnotationVisitor(fn_node, namespace)
+        self.expr_visitor = _LocalExpressionVisitor()
         namespace.update(self.func.arguments)
 
-        if self.func.visibility is FunctionVisibility.INTERNAL:
-            node_list = fn_node.get_descendants(
-                vy_ast.Attribute, {"value.id": "msg", "attr": {"data", "sender"}}
-            )
-            if node_list:
-                raise StateAccessViolation(
-                    f"msg.{node_list[0].attr} is not allowed in internal functions", node_list[0]
-                )
         if self.func.mutability == StateMutability.PURE:
             node_list = fn_node.get_descendants(
                 vy_ast.Attribute,
@@ -175,21 +207,6 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
         super().visit(node)
         self.annotation_visitor.visit(node)
 
-        attr_descendants = node.get_descendants(vy_ast.Attribute)
-        for attr_descendant in attr_descendants:
-            self.visit(attr_descendant)
-
-    def visit_Attribute(self, node):
-        if node.get("value.id") == "msg" and node.attr == "data":
-            parent = node.get_ancestor()
-            if parent.get("func.id") not in ("slice", "len"):
-                raise SyntaxException(
-                    "msg.data is only allowed inside of the slice or len functions",
-                    node.node_source_code,
-                    node.lineno,
-                    node.col_offset,
-                )
-
     def visit_AnnAssign(self, node):
         name = node.get("target.id")
         if name is None:
@@ -207,41 +224,45 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
             self.namespace[name] = type_definition
         except VyperException as exc:
             raise exc.with_annotation(node) from None
+        self.expr_visitor.visit(node.value)
 
     def visit_Assign(self, node):
         if isinstance(node.value, vy_ast.Tuple):
             raise StructureException("Right-hand side of assignment cannot be a tuple", node.value)
+
         target = get_exact_type_from_node(node.target)
+
         validate_expected_type(node.value, target)
-        if self.func.mutability <= StateMutability.VIEW and target.location == DataLocation.STORAGE:
-            raise StateAccessViolation(
-                f"Cannot modify storage in a {self.func.mutability.value} function", node
-            )
-        target.validate_modification(node)
+        target.validate_modification(node, self.func.mutability)
+
+        self.expr_visitor.visit(node.value)
 
     def visit_AugAssign(self, node):
         if isinstance(node.value, vy_ast.Tuple):
             raise StructureException("Right-hand side of assignment cannot be a tuple", node.value)
+
         target = get_exact_type_from_node(node.target)
+
         validate_expected_type(node.value, target)
-        if self.func.mutability <= StateMutability.VIEW and target.location == DataLocation.STORAGE:
-            raise StateAccessViolation(
-                f"Cannot modify storage in a {self.func.mutability.value} function", node
-            )
-        target.validate_modification(node)
+        target.validate_modification(node, self.func.mutability)
+
+        self.expr_visitor.visit(node.value)
 
     def visit_Raise(self, node):
         if node.exc:
             _validate_revert_reason(node.exc)
+            self.expr_visitor.visit(node.exc)
 
     def visit_Assert(self, node):
         if node.msg:
             _validate_revert_reason(node.msg)
+            self.expr_visitor.visit(node.msg)
 
         try:
             validate_expected_type(node.test, BoolDefinition())
         except InvalidType:
             raise InvalidType("Assertion test value must be a boolean", node.test)
+        self.expr_visitor.visit(node.test)
 
     def visit_Return(self, node):
         values = node.value
@@ -266,9 +287,11 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                 validate_expected_type(given, expected)
         else:
             validate_expected_type(values, self.func.return_type)
+        self.expr_visitor.visit(node.value)
 
     def visit_If(self, node):
         validate_expected_type(node.test, BoolDefinition())
+        self.expr_visitor.visit(node.test)
         with self.namespace.enter_scope():
             for n in node.body:
                 self.visit(n)
@@ -295,7 +318,7 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                     raise StateAccessViolation("Value must be a literal", node)
                 if args[0].value <= 0:
                     raise StructureException("For loop must have at least 1 iteration", args[0])
-                validate_expected_type(args[0], Uint256Definition())
+                validate_expected_type(args[0], IntegerAbstractType())
                 type_list = get_possible_types_from_node(args[0])
             else:
                 validate_expected_type(args[0], IntegerAbstractType())
@@ -334,18 +357,12 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
             type_list = [
                 i.value_type
                 for i in get_possible_types_from_node(node.iter)
-                if isinstance(i, ArrayDefinition)
+                if isinstance(i, (DynamicArrayDefinition, ArrayDefinition))
             ]
 
         if not type_list:
             raise InvalidType("Not an iterable type", node.iter)
 
-        if next((i for i in type_list if isinstance(i, ArrayDefinition)), False):
-            raise StructureException("Cannot iterate over a nested list", node.iter)
-
-        if next((i for i in type_list if isinstance(i, StructDefinition)), False):
-            raise StructureException("Cannot iterate over a list of structs", node.iter)
-
         if isinstance(node.iter, (vy_ast.Name, vy_ast.Attribute)):
             # check for references to the iterated value within the body of the loop
             assign = _check_iterator_assign(node.iter, node)
@@ -376,6 +393,7 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                             f"which potentially modifies iterated storage variable '{iter_name}'",
                             call_node,
                         )
+        self.expr_visitor.visit(node.iter)
 
         for_loop_exceptions = []
         iter_name = node.target.id
@@ -441,11 +459,20 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                     f"Cannot call any function from a {self.func.mutability.value} function", node
                 )
 
+        if isinstance(fn_type, MemberFunctionDefinition) and fn_type.is_modifying:
+            fn_type.underlying_type.validate_modification(node, self.func.mutability)
+
+        # NOTE: fetch_call_return validates call args.
         return_value = fn_type.fetch_call_return(node.value)
-        if return_value and not isinstance(fn_type, ContractFunction):
+        if (
+            return_value
+            and not isinstance(fn_type, MemberFunctionDefinition)
+            and not isinstance(fn_type, ContractFunction)
+        ):
             raise StructureException(
                 f"Function '{fn_type._id}' cannot be called without assigning the result", node
             )
+        self.expr_visitor.visit(node.value)
 
     def visit_Log(self, node):
         if not isinstance(node.value, vy_ast.Call):
@@ -454,3 +481,57 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
         if not isinstance(event, Event):
             raise StructureException("Value is not an event", node.value)
         event.fetch_call_return(node.value)
+        self.expr_visitor.visit(node.value)
+
+
+class _LocalExpressionVisitor(VyperNodeVisitorBase):
+    ignored_types = (vy_ast.Constant, vy_ast.Name)
+    scope_name = "function"
+
+    def visit_Attribute(self, node: vy_ast.Attribute) -> None:
+        self.visit(node.value)
+        _validate_msg_data_attribute(node)
+        _validate_address_code_attribute(node)
+
+    def visit_BinOp(self, node: vy_ast.BinOp) -> None:
+        self.visit(node.left)
+        self.visit(node.right)
+
+    def visit_BoolOp(self, node: vy_ast.BoolOp) -> None:
+        for value in node.values:  # type: ignore[attr-defined]
+            self.visit(value)
+
+    def visit_Call(self, node: vy_ast.Call) -> None:
+        self.visit(node.func)
+        for arg in node.args:
+            self.visit(arg)
+        for kwarg in node.keywords:
+            self.visit(kwarg.value)
+
+    def visit_Compare(self, node: vy_ast.Compare) -> None:
+        self.visit(node.left)  # type: ignore[attr-defined]
+        self.visit(node.right)  # type: ignore[attr-defined]
+
+    def visit_Dict(self, node: vy_ast.Dict) -> None:
+        for key in node.keys:
+            self.visit(key)
+        for value in node.values:
+            self.visit(value)
+
+    def visit_Index(self, node: vy_ast.Index) -> None:
+        self.visit(node.value)
+
+    def visit_List(self, node: vy_ast.List) -> None:
+        for element in node.elements:
+            self.visit(element)
+
+    def visit_Subscript(self, node: vy_ast.Subscript) -> None:
+        self.visit(node.value)
+        self.visit(node.slice)
+
+    def visit_Tuple(self, node: vy_ast.Tuple) -> None:
+        for element in node.elements:
+            self.visit(element)
+
+    def visit_UnaryOp(self, node: vy_ast.UnaryOp) -> None:
+        self.visit(node.operand)  # type: ignore[attr-defined]
